interface TradesFeedOptions {
    reconnectionIntervalMs?: number;
    reconnectionMaxAttempts?: number;
}
export interface TradesFeedSubscribeParams {
    pairId?: string;
    paidIds?: string[];
    accountIds?: string[];
    mintIds?: string[];
}
export interface TradesFeedUnsubscribeParams {
    pairId?: string;
}
export interface Trade {
    slot: number;
    parse_time_ms: number;
    txn_time_seconds: number;
    signature: string;
    broker: string;
    market_key: string;
    base_token_mint: string;
    quote_token_mint: string;
    price: number;
    size: number;
    signer: string;
    taker_side: string;
}
export interface TradeUpdate {
    TradeUpdate: {
        status: 'new' | 'revoke';
        trade: Trade;
    };
}
export declare function isTradeUpdate(obj: any): obj is TradeUpdate;
interface StatusMessage {
    success: boolean;
    message: string;
}
export declare class TradesFeed {
    private _url;
    protected _socket: WebSocket;
    private _connected;
    private _reconnectionIntervalMs;
    private _reconnectionMaxAttempts;
    private _reconnectionAttempts;
    private _onConnect;
    private _onDisconnect;
    private _onMessage;
    private _onTrade;
    private _onStatus;
    constructor(url: string, options?: TradesFeedOptions);
    disconnect(): void;
    connected(): boolean;
    onConnect(callback: () => void): void;
    onDisconnect(callback: (reconnectionAttemptsExhausted: boolean) => void): void;
    onMessage(callback: (data: any) => void): void;
    onTrade(callback: (update: TradeUpdate) => void): void;
    onStatus(callback: (status: StatusMessage) => void): void;
    subscribe(subscriptions: TradesFeedSubscribeParams): void;
    unsubscribe(params: TradesFeedUnsubscribeParams): void;
    private _connect;
    private _reconnectionAttemptsExhausted;
}
export {};
//# sourceMappingURL=fills.d.ts.map